@@ -5,7 +5,7 @@ import numpy as np
 from monty.serialization import loadfn
 from pymatgen import Spin
 
-from ifermi.fermi_surface import FermiSurface
+from ifermi.surface import FermiSurface
 
 test_dir = Path(__file__).resolve().parent
 
@@ -18,30 +18,23 @@ class FermiSurfaceTest(unittest.TestCase):
         # for some reason BandStructure json doesn't include the structure
         self.band_structure.structure = bs_data["structure"]
 
-        self.kpoint_dim = bs_data["dim"]
         self.ref_fs_wigner = loadfn(test_dir / "fs_BaFe2As2_wigner.json.gz")
         self.ref_fs_reciprocal = loadfn(test_dir / "fs_BaFe2As2_reciprocal.json.gz")
 
     def test_wigner_seitz_cell(self):
-        fs = FermiSurface.from_band_structure(
-            self.band_structure, self.kpoint_dim, wigner_seitz=True
-        )
+        fs = FermiSurface.from_band_structure(self.band_structure, wigner_seitz=True)
         self.assert_fs_equal(fs, self.ref_fs_wigner)
 
     def test_decimation(self):
-        fs = FermiSurface.from_band_structure(self.band_structure, self.kpoint_dim)
-        n_faces_orig = len(fs.isosurfaces[Spin.up][0][1])
+        fs = FermiSurface.from_band_structure(self.band_structure)
+        n_faces_orig = len(fs.isosurfaces[Spin.up][0].faces)
 
-        fs = FermiSurface.from_band_structure(
-            self.band_structure, self.kpoint_dim, decimate_factor=0.8
-        )
-        n_faces_new = len(fs.isosurfaces[Spin.up][0][1])
+        fs = FermiSurface.from_band_structure(self.band_structure, decimate_factor=0.8)
+        n_faces_new = len(fs.isosurfaces[Spin.up][0].faces)
         self.assertLess(n_faces_new, n_faces_orig)
 
     def test_reciprocal_cell(self):
-        fs = FermiSurface.from_band_structure(
-            self.band_structure, self.kpoint_dim, wigner_seitz=False
-        )
+        fs = FermiSurface.from_band_structure(self.band_structure, wigner_seitz=False)
         self.assert_fs_equal(fs, self.ref_fs_reciprocal)
 
     def assert_fs_equal(self, fs1: FermiSurface, fs2: FermiSurface):
@@ -65,7 +58,9 @@ class FermiSurfaceTest(unittest.TestCase):
 
             for s1, s2 in zip(iso1, iso2):
                 # check vertex coordinates are almost equal
-                np.testing.assert_array_almost_equal(s1[0], s2[0], decimal=5)
+                np.testing.assert_array_almost_equal(
+                    s1.vertices, s2.vertices, decimal=5
+                )
 
                 # check faces are exactly equal
-                np.testing.assert_array_equal(s1[1], s2[1])
+                np.testing.assert_array_equal(s1.faces, s2.faces)
